# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-05-09 16:46
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserMeta',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.SlugField(help_text=b'The ID name of this bit of data. Should be only lowercase numbers and letters, dashes or underscores. No spaces.')),
                ('value', models.TextField(help_text=b'The value, data or code for this item')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='meta', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'user metadata',
            },
        ),
        migrations.AlterUniqueTogether(
            name='usermeta',
            unique_together=set([('user', 'key')]),
        ),
    ]
